==> zio-aws-ec2_2.12-5.19.12.1-sources.jar: zio/aws/ec2/model/CreateVpnGatewayRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateVpnGatewayRequest(
    availabilityZone: Optional[String] = Optional.Absent,
    `type`: zio.aws.ec2.model.GatewayType,
    tagSpecifications: Optional[Iterable[zio.aws.ec2.model.TagSpecification]] =
      Optional.Absent,
    amazonSideAsn: Optional[Long] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest = {
    import CreateVpnGatewayRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
      .builder()
      .optionallyWith(availabilityZone.map(value => value: java.lang.String))(
        _.availabilityZone
      )
      .`type`(`type`.unwrap)
      .optionallyWith(
        tagSpecifications.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagSpecifications)
      .optionallyWith(amazonSideAsn.map(value => value: java.lang.Long))(
        _.amazonSideAsn
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CreateVpnGatewayRequest.ReadOnly =
    zio.aws.ec2.model.CreateVpnGatewayRequest.wrap(buildAwsValue())
}
object CreateVpnGatewayRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateVpnGatewayRequest =
      zio.aws.ec2.model.CreateVpnGatewayRequest(
        availabilityZone.map(value => value),
        `type`,
        tagSpecifications.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        amazonSideAsn.map(value => value)
      )
    def availabilityZone: Optional[String]
    def `type`: zio.aws.ec2.model.GatewayType
    def tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]]
    def amazonSideAsn: Optional[Long]
    def getAvailabilityZone: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getType: ZIO[Any, Nothing, zio.aws.ec2.model.GatewayType] =
      ZIO.succeed(`type`)
    def getTagSpecifications: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TagSpecification.ReadOnly
    ]] = AwsError.unwrapOptionField("tagSpecifications", tagSpecifications)
    def getAmazonSideAsn: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("amazonSideAsn", amazonSideAsn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
  ) extends zio.aws.ec2.model.CreateVpnGatewayRequest.ReadOnly {
    override val availabilityZone: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.availabilityZone())
      .map(value => value: String)
    override val `type`: zio.aws.ec2.model.GatewayType =
      zio.aws.ec2.model.GatewayType.wrap(impl.`type`())
    override val tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagSpecifications())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.TagSpecification.wrap(item)
          }.toList
        )
    override val amazonSideAsn: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.amazonSideAsn())
      .map(value => value: Long)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
  ): zio.aws.ec2.model.CreateVpnGatewayRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/CreateVpnGatewayRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateVpnGatewayRequest(
    availabilityZone: Optional[String] = Optional.Absent,
    `type`: zio.aws.ec2.model.GatewayType,
    tagSpecifications: Optional[Iterable[zio.aws.ec2.model.TagSpecification]] =
      Optional.Absent,
    amazonSideAsn: Optional[Long] = Optional.Absent,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest = {
    import CreateVpnGatewayRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
      .builder()
      .optionallyWith(availabilityZone.map(value => value: java.lang.String))(
        _.availabilityZone
      )
      .`type`(`type`.unwrap)
      .optionallyWith(
        tagSpecifications.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tagSpecifications)
      .optionallyWith(amazonSideAsn.map(value => value: java.lang.Long))(
        _.amazonSideAsn
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CreateVpnGatewayRequest.ReadOnly =
    zio.aws.ec2.model.CreateVpnGatewayRequest.wrap(buildAwsValue())
}
object CreateVpnGatewayRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateVpnGatewayRequest =
      zio.aws.ec2.model.CreateVpnGatewayRequest(
        availabilityZone.map(value => value),
        `type`,
        tagSpecifications.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        amazonSideAsn.map(value => value),
        dryRun.map(value => value)
      )
    def availabilityZone: Optional[String]
    def `type`: zio.aws.ec2.model.GatewayType
    def tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]]
    def amazonSideAsn: Optional[Long]
    def dryRun: Optional[Boolean]
    def getAvailabilityZone: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("availabilityZone", availabilityZone)
    def getType: ZIO[Any, Nothing, zio.aws.ec2.model.GatewayType] =
      ZIO.succeed(`type`)
    def getTagSpecifications: ZIO[Any, AwsError, List[
      zio.aws.ec2.model.TagSpecification.ReadOnly
    ]] = AwsError.unwrapOptionField("tagSpecifications", tagSpecifications)
    def getAmazonSideAsn: ZIO[Any, AwsError, Long] =
      AwsError.unwrapOptionField("amazonSideAsn", amazonSideAsn)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
  ) extends zio.aws.ec2.model.CreateVpnGatewayRequest.ReadOnly {
    override val availabilityZone: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.availabilityZone())
      .map(value => value: String)
    override val `type`: zio.aws.ec2.model.GatewayType =
      zio.aws.ec2.model.GatewayType.wrap(impl.`type`())
    override val tagSpecifications
        : Optional[List[zio.aws.ec2.model.TagSpecification.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagSpecifications())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.TagSpecification.wrap(item)
          }.toList
        )
    override val amazonSideAsn: Optional[Long] = zio.aws.core.internal
      .optionalFromNullable(impl.amazonSideAsn())
      .map(value => value: Long)
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateVpnGatewayRequest
  ): zio.aws.ec2.model.CreateVpnGatewayRequest.ReadOnly = new Wrapper(impl)
}
